@@ -22,27 +22,53 @@ import numpy as np
 # https://casaguides.nrao.edu/index.php/Corrupting_Simulated_Data_(Simulator_Tool)
 # https://library.nrao.edu/public/memos/alma/main/memo128.pdf
 
-def calc_a_noise(vis,uvw,beam_model_map,eval_beam_models, antenna1, antenna2, noise_parms):
+#def calc_a_noise(vis,uvw,beam_model_map,eval_beam_models, antenna1, antenna2, noise_parms):
+#    return 0
+
+def calc_a_noise_chunk(vis_shape,uvw,beam_model_map,eval_beam_models, antenna1, antenna2, noise_parms):
     """
     Add noise to visibilities.
     
     Parameters
     ----------
-    vis : np.array
+    vis_shape : np.array
+    noise_parms: dict
+    Set various system parameters from which the thermal (ie, random additive) noise level will be calculated.
+    See https://casadocs.readthedocs.io/en/stable/api/tt/casatools.simulator.html#casatools.simulator.simulator.setnoise.
+    noise_parms['mode']: str, default='tsys-manuel', options=['simplenoise','tsys-manuel','tsys-atm']
+    Currently only 'tsys-manuel' is implemented.
+    noise_parms['t_atmos']: , float, default = 250.0, Kelvin
+    Temperature of atmosphere (mode='tsys-manual')
+    noise_parms['tau']: float, default = 0.1
+    Zenith Atmospheric Opacity (if tsys-manual). Currently the effect of Zenith Atmospheric Opacity (Tau) is not included in the noise modeling.
+    noise_parms['ant_efficiency']: float, default=0.8
+    Antenna efficiency
+    noise_parms['spill_efficiency']: float, default=0.85
+    Forward spillover efficiency.
+    noise_parms['corr_efficiency']: float, default=0.88
+    Correlation efficiency.
+    noise_parms['t_receiver']: float, default=50.0, Kelvin
+    Receiver temp (ie, all non-atmospheric Tsys contributions).
+    noise_parms['t_ground']: float, default=270.0, Kelvin
+    Temperature of ground/spill.
+    noise_parms['t_cmb']: float, default=2.725, Kelvin
+    Cosmic microwave background temperature.
+    noise_parms['auto_corr']: bool, default=False
+    If True autocorrelations are also calculated.
+    noise_parms['freq_resolution']: float, Hz
+    Width of a single channel.
+    noise_parms['time_delta']: float, s
+    Integration time.
     Returns
     -------
-    vis : np.array
+    noise : np.array
     """
-    from ._sirius_utils._constants import k_B
-    noise = np.zeros(vis.shape,dtype=np.complex)
-    
-    n_time, n_baseline, n_chan, n_pol = vis.shape
+    from sirius_data._constants import k_B
+    n_time, n_baseline, n_chan, n_pol = vis_shape
     dish_sizes = get_dish_sizes(eval_beam_models)
     
     #For now tau (Zenith Atmospheric Opacity) will be set to 0 (don't have to do elevation calculation)
-    twiddle = 100
-    #print('Twiddle 2 is active.', twiddle)
-    factor = (4*np.sqrt(2)*k_B*(10**23))/(noise_parms['ant_efficiency']*noise_parms['corr_efficiency']*np.pi)*twiddle
+    factor = (4*np.sqrt(2)*k_B*(10**23))/(noise_parms['ant_efficiency']*noise_parms['corr_efficiency']*np.pi)
     
     
     t_sys = noise_parms['t_receiver'] + noise_parms['t_atmos']*(1-noise_parms['spill_efficiency']) + noise_parms['t_cmb']
@@ -64,7 +90,7 @@ def calc_a_noise(vis,uvw,beam_model_map,eval_beam_models, antenna1, antenna2, no
         noise_re = np.random.normal(loc=0.0,scale=sigma_full_dim)
         noise_im = np.random.normal(loc=0.0,scale=sigma_full_dim)
         
-        vis = vis + noise_re + 1j*noise_im
+        noise = noise_re + 1j*noise_im
     else:
         #Most probaly will have to include the autocorrelation weight.
         auto_corr_mask = ((uvw[:,:,0]!=0) & (uvw[:,:,1]!=0)).astype(int)
@@ -75,9 +101,9 @@ def calc_a_noise(vis,uvw,beam_model_map,eval_beam_models, antenna1, antenna2, no
         noise_re = np.random.normal(loc=0.0,scale=sigma_full_dim*auto_corr_scale[:,:,None,None])
         noise_im = np.random.normal(loc=0.0,scale=sigma_full_dim)
         
-        vis = vis + noise_re + 1j*noise_im*auto_corr_mask[:,:,None,None]
+        noise = noise_re + 1j*noise_im*auto_corr_mask[:,:,None,None]
     
-    return vis, np.tile(weight[:,:,None],(1,1,n_pol)), np.tile(sigma[:,:,None],(1,1,n_pol))
+    return noise, np.tile(weight[:,:,None],(1,1,n_pol)), np.tile(sigma[:,:,None],(1,1,n_pol))
     
     
 def get_dish_sizes(eval_beam_models):
